"""
进行数据替换，实现数据动态化
"""
import re
import json

from Common.handle_envdata import EnvData

# 将字典类型转化成字符串，进行替换，将字符串转换成字典
def replace_case_by_regular(case):
    # 将字典转换成字符串,false是能正确获取中文
    data_str = json.dumps(case, ensure_ascii=False)
    # 调用替换函数
    data_new = replace_by_regular(data_str)
    # 将字符串转换成字典
    data_dic = json.loads(data_new)
    return data_dic

# 通过正则表达式替换
def replace_by_regular(data):
    # 通过正则表达式来获取需求替换的数据
    res = re.findall("#(.*?)#", data)
    # 如何没有获取到数据就不进行替换操作
    if res:
        # 先通过set去重，结果为集合，如何利用list转换成列表
        res_new = list(set(res))
        for item in res_new:
            try:
                # 获取需要替换的数据，数据都在envdata类中，存储全局变量
                value = getattr(EnvData, item)
                data = data.replace("#{}#".format(item), str(value))
            except AttributeError:
                continue
    return data

# 通过占位符替换
def replace_mark_with_data(case, mark, real_data):
    for key, value in case.items():
        # 判断value不为空并且是一个字符串
        if value is not None and isinstance(value, str):
            if value.find(mark) != -1:
                case[key] = value.replace(mark, real_data)
    return case


if __name__ == '__main__':
    case = {'id': 2, 'title': '充值成功，充值200.22', 'url': '/member/recharge', 'method': 'post',
        'request_data': '{\n    "member_id": "#member_id#",\n    "amount": 200.22\n}', 'code': 0,
        'expected': '{\n    "code": 0,\n    "msg": "OK",\n    "data": {\n        "id": #member_id#,\n        "leave_amount": #leave_amount#\n    }\n}',
        'check_sql': 'select CAST(leave_amount AS CHAR) AS leave_amount FROM member WHERE id = "#member_id#";'}
    data_str = json.dumps(case, ensure_ascii=False)
    print(data_str)
    res = re.findall("#(.*?)#", data_str)
    print(res)

    # if case["request_data"].find("#new_phone#"):
    #     case = replace_mark_with_data(case, "#new_phone#", "12345678901")
    # for key, value in case.items():
    #     print(key, value)
