import os.path
import pytest
import time

from Common.handle_excel import HandleExcel
from Common.handle_path import datas_dir
from Common.my_logger import logger
from Common.handle_phone import get_new_phone
from Common.handle_data import replace_case_by_regular
from Common.handle_envdata import EnvData
from Common.handle_requests import send_request
from Common.handle_extract_data_from_response import extract_data_from_response
from Common.handle_db import HandleDB


@pytest.fixture(scope="class")
def get_newPhone():
    logger.info("************ 优才流程 开始执行 ***************")
    db = HandleDB()
    # 获取手机号码
    mobile = get_new_phone(db)
    # 设置手机号码为全局变量
    setattr(EnvData, "mobile", mobile)
    setattr(EnvData, "username", "接口自动化-测试")
    # setattr(EvnData, "copywriter_id", 1391)
    yield db
    db.close()
    logger.info("************ 优才流程 执行结束 ***************")


@pytest.mark.usefixtures("get_newPhone")
class TestTalentedPerson:
    print(get_newPhone)
    # 第一步，读取excel中的数据
    exc = HandleExcel(os.path.join(datas_dir, "接口业务流.xlsx"), "优才")
    cases = exc.read_all_datas()
    # 关闭excel
    exc.close_file()

    print(cases)

    # # 如果存在distribution变量，说明该订单被分配了，需要跳过分配客户接口
    # if hasattr(EnvData, "distribution"):
    #     del cases[12:15]

    @pytest.mark.parametrize("case", cases)
    def test_talented_person(self, case, get_newPhone):
        logger.info("**********  执行用例{}：{}  **********".format(case["id"], case["title"]))
        # 第二步，替换request_data中的未知数
        case = replace_case_by_regular(case)
        # print(case)

        # 第三步，执行请求
        if hasattr(EnvData, "token"):
            if case["title"] == "提交修改后的文档":
                time.sleep(90)
                id_list = getattr(EnvData, "id_list")
                dic = {}
                for i in range(len(id_list)):
                    dic["id"] = id_list[i]
                    response = send_request(case["method"], case["url"], dic, token=getattr(EnvData, "token"),
                                            Authorization=getattr(EnvData, "client_token"))
                time.sleep(90)
            elif case["title"] == "提交":
                response = send_request(case["method"], case["url"], case["request_data"],
                                        token=getattr(EnvData, "token"),
                                        Authorization=getattr(EnvData, "client_token"))
            else:
                response = send_request(case["method"], case["url"], case["request_data"],
                                        token=getattr(EnvData, "token"))
        else:
            response = send_request(case["method"], case["url"], case["request_data"])

        # 第四步，将extract_data中表达式的值设置为全局变量
        if case["extract_data"]:
            extract_data_from_response(case["extract_data"], response.json())

        # 第五步，执行sql
        # 任务流转接口
        if case["check_sql"] and case["check_keyword"] == "order_task_id":
            order_task_id = get_newPhone.select_one_data(case["check_sql"])["id"]
            setattr(EnvData, "order_task_id", order_task_id)
        elif case["check_sql"] and case["check_keyword"] == "id_list":
            ids = get_newPhone.select_all_data(case["check_sql"])
            id_list = []
            for i in ids:
                id_list.append(i["id"])
            print(id_list)
            setattr(EnvData, "id_list", id_list)

        # 第五步，断言
        assert response.json()["code"] == 200
